#include "stm8s.h"
#include "utils.h"

//Initialize the UART1
void UART1_Configuration(void){
	CLK_PeripheralClockConfig(CLK_PERIPHERAL_UART1,ENABLE); 
	UART1_Init((u32)115200, UART1_WORDLENGTH_8D, UART1_STOPBITS_1, UART1_PARITY_NO, UART1_SYNCMODE_CLOCK_DISABLE, UART1_MODE_TXRX_ENABLE);

	UART1_SetPrescaler(0x01);
	UART1_Cmd(ENABLE);
}

unsigned char UART1_Get(void){
	UART1_ClearFlag(UART1_FLAG_RXNE);
	while(RESET==UART1_GetFlagStatus(UART1_FLAG_RXNE));
	return UART1_ReceiveData8();
}

void UART1_Put(char chr){
	UART1_SendData8(chr);
	while(UART1_GetFlagStatus(UART1_FLAG_TXE) == RESET);	
}

void sendU16(const u16 integer){
	u8* components = (u8*)(&integer);
	UART1_Put(components[0]);
	UART1_Put(components[1]);
}

//Send a string
void UART1_Puts(const char* str){
	while (*str){
		UART1_SendData8(*str);
		while(UART1_GetFlagStatus(UART1_FLAG_TXE) == RESET);
		str++;
	}
}

//Convert a unsigned long integer to string, in str
void u32tostr(unsigned long dat,unsigned char *str){
	u8 temp[20];
	u8 i=0, j=0;
	
	while(dat){
		temp[i] = dat%10 + 0x30;
		i++;
		dat /= 10;
	}
	
	j=i;
	for(i=0;i<j;i++)
		str[i]=temp[j-i-1];
			
	if(!i)
		str[i++]='0';
	str[i]=0;
}

//Send a number
void UART1_Send_Num(unsigned long dat){
	u8 temp[20];
	u32tostr(dat,temp);
	UART1_Puts(temp);
}

//Send debug information (string prompt + number)
void UART1_Send_Inf(unsigned char *info,unsigned long dat){
	UART1_Puts(info);
	UART1_Send_Num(dat);
	UART1_Puts("\r\n");  
}
